### TODO ideas
 * specify the type of charts: area, line, etc...
 * if data columns have different scale/range, use multiple Y-axis or left/right
 * use timeseries for x-axis
 * use "steps" in charts
 * store both data/html into a file that that can be "served"
 * allow to upload the chartable data to "the cloud" or at known file/data repo
 * store the data compressed
 * use a bit.ly type of short/random URL to access to saved data
 * along with the normal describe stats add sum()
 * when a delimiter is specified such as |, assume \s*|\s*
 * combine the output of describe() and info()
 * look for Exploratory Data Analysis (EDA) techniques
 * Missing data?